SignatureField class

Inheritance

Constructors

SignatureField({Key? key, String? label, SignatureData? value, ValueChanged<SignatureData?>? onChanged, FormFieldValidator<SignatureData>? validator, InputDecoration? decoration, SignatureConfig config = const SignatureConfig(), double height = 200.0, double? width, BorderRadius? borderRadius, Border? border, SignatureType signatureType = SignatureType.handwritten, AuthenticationLevel authLevel = AuthenticationLevel.basic, bool showClearButton = true, bool showSaveButton = false, bool showUndoRedoButtons = true, bool enableZoom = false, bool enableFullScreen = true, bool enableRotation = false, bool enableResize = false, String? clearButtonText, String? saveButtonText, String? undoButtonText, String? redoButtonText, bool enableImageExport = true, bool enablePdfExport = false, bool enableSvgExport = false, bool enableBiometricExport = false, double exportScale = 2.0, List<ExportFormat> supportedFormats = const [ExportFormat.png], bool enableBiometricCapture = false, bool enableStrokeAnalysis = false, bool enableTimingAnalysis = false, bool enablePressureAnalysis = false, bool enableVelocityAnalysis = false, bool enableDigitalSigning = false, bool enableEncryption = false, bool enableWatermark = false, bool enableIntegrityCheck = false, String? certificatePath, String? privateKeyPath, Color? backgroundColor, Color? borderColor, Widget? placeholder, TextStyle? labelStyle, EdgeInsets? padding, bool showSignatureInfo = false, bool showBiometricInfo = false, bool enableGestures = true, bool enableVelocityBasedWidth = false, bool enableMultiTouch = false, bool enablePalmRejection = false, bool enableAutoSmoothing = true, bool enableStrokeRecognition = false, bool enableRealTimeSync = false, bool enableVersionControl = false, bool enableComments = false, bool enableSharing = false, dynamic onCommentAdded(SignatureData signature, String comment)?, bool enableAnalytics = false, bool enablePerformanceMonitoring = false, dynamic onAnalyticsEvent(Map<String, dynamic> analyticsData)?, int? minStrokeCount, double? minSignatureWidth, double? minSignatureHeight, double? minComplexityScore, Duration? maxSigningTime, Duration? minSigningTime, dynamic onSignatureStart(SignatureData signature)?, dynamic onSignatureEnd(SignatureData signature)?, dynamic onError(String error)?, dynamic onBiometricsCaptured(BiometricProperties biometrics)?, dynamic onDigitalSigningComplete(SignatureData signature)?})
const

Properties

authLevel → AuthenticationLevel
final
backgroundColor → Color?
final
border → Border?
final
borderColor → Color?
final
borderRadius → BorderRadius?
final
certificatePath → String?
final
clearButtonText → String?
final
config → SignatureConfig
final
decoration → InputDecoration?
final
enableAnalytics → bool
final
enableAutoSmoothing → bool
final
enableBiometricCapture → bool
final
enableBiometricExport → bool
final
enableComments → bool
final
enableDigitalSigning → bool
final
enableEncryption → bool
final
enableFullScreen → bool
final
enableGestures → bool
final
enableImageExport → bool
final
enableIntegrityCheck → bool
final
enableMultiTouch → bool
final
enablePalmRejection → bool
final
enablePdfExport → bool
final
enablePerformanceMonitoring → bool
final
enablePressureAnalysis → bool
final
enableRealTimeSync → bool
final
enableResize → bool
final
enableRotation → bool
final
enableSharing → bool
final
enableStrokeAnalysis → bool
final
enableStrokeRecognition → bool
final
enableSvgExport → bool
final
enableTimingAnalysis → bool
final
enableVelocityAnalysis → bool
final
enableVelocityBasedWidth → bool
final
enableVersionControl → bool
final
enableWatermark → bool
final
enableZoom → bool
final
exportScale → double
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String?
final
labelStyle → TextStyle?
final
maxSigningTime → Duration?
final
minComplexityScore → double?
final
minSignatureHeight → double?
final
minSignatureWidth → double?
final
minSigningTime → Duration?
final
minStrokeCount → int?
final
onAnalyticsEvent → dynamic Function(Map<String, dynamic> analyticsData)?
final
onBiometricsCaptured → dynamic Function(BiometricProperties biometrics)?
final
onChanged → ValueChanged<SignatureData?>?
final
onCommentAdded → dynamic Function(SignatureData signature, String comment)?
final
onDigitalSigningComplete → dynamic Function(SignatureData signature)?
final
onError → dynamic Function(String error)?
final
onSignatureEnd → dynamic Function(SignatureData signature)?
final
onSignatureStart → dynamic Function(SignatureData signature)?
final
padding → EdgeInsets?
final
placeholder → Widget?
final
privateKeyPath → String?
final
redoButtonText → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saveButtonText → String?
final
showBiometricInfo → bool
final
showClearButton → bool
final
showSaveButton → bool
final
showSignatureInfo → bool
final
showUndoRedoButtons → bool
final
signatureType → SignatureType
final
supportedFormats → List<ExportFormat>
final
undoButtonText → String?
final
validator → FormFieldValidator<SignatureData>?
final
value → SignatureData?
final
width → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<SignatureField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited